polar2grid.readers.avhrr\_l1b\_aapp module
==========================================

.. automodule:: polar2grid.readers.avhrr_l1b_aapp
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
